@@ -11,6 +11,10 @@ const (
 	// controllerDaemonSetLabel identifies a daemonset as a dns
 	// daemonset, and the value is the name of the owning dns.
 	controllerDaemonSetLabel = "dns.operator.openshift.io/daemonset-dns"
+
+	// MetricsServingCertAnnotation is the annotation needed to generate
+	// the certificates for secure DNS metrics.
+	MetricsServingCertAnnotation = "service.beta.openshift.io/serving-cert-secret-name"
 )
 
 // DNSDaemonSetName returns the namespaced name for the dns daemonset.
@@ -53,3 +57,7 @@ func DNSServiceMonitorName(dns *operatorv1.DNS) types.NamespacedName {
 		Name:      "dns-" + dns.Name,
 	}
 }
+
+func DNSMetricsSecretName(dns *operatorv1.DNS) string {
+	return "dns-" + dns.Name + "-metrics-tls"
+}
